@@ -138,7 +138,7 @@ class DefaultTransitTemplateGenerator(TransitTemplateGenerator):
 
     def calculate_results(self, no_transits_were_fit, chi2, chi2red, chi2_min, chi2red_min, test_statistic_periods,
                           test_statistic_depths, transitleastsquares, lc_arr, best_row, period_grid, durations,
-                          duration, maxwidth_in_samples):
+                          duration, maxwidth_in_samples, chi2_baseline):
         """
         Returns a transitleastsquaresresult for the given template
         """
@@ -195,7 +195,7 @@ class DefaultTransitTemplateGenerator(TransitTemplateGenerator):
             after_transit_count = numpy.nan
             before_transit_count = numpy.nan
         else:
-            SR, power_raw, power, SDE_raw, SDE = spectra(chi2, transitleastsquares.oversampling_factor)
+            SR, power_raw, power, SDE_raw, SDE = spectra(chi2, transitleastsquares.oversampling_factor, chi2_baseline)
             index_highest_power = numpy.argmax(power)
             period = test_statistic_periods[index_highest_power]
             depth = test_statistic_depths[index_highest_power]
